@@ -19,7 +19,15 @@
 #include <KCrash>
 #include <KDBusService>
 #include <KLocalizedString>
+#define HAVE_KICONTHEME __has_include(<KIconTheme>)
+#if HAVE_KICONTHEME
+#include <KIconTheme>
+#endif
 
+#define HAVE_STYLE_MANAGER __has_include(<KStyleManager>)
+#if HAVE_STYLE_MANAGER
+#include <KStyleManager>
+#endif
 // KShisen
 #include "app.h"
 #include "debug.h"
@@ -27,7 +35,17 @@
 
 int main(int argc, char ** argv)
 {
+#if HAVE_KICONTHEME
+    KIconTheme::initTheme();
+#endif
     QApplication a(argc, argv);
+#if HAVE_STYLE_MANAGER
+    KStyleManager::initStyle();
+#else // !HAVE_STYLE_MANAGER
+#if defined(Q_OS_MACOS) || defined(Q_OS_WIN)
+    QApplication::setStyle(QStringLiteral("breeze"));
+#endif // defined(Q_OS_MACOS) || defined(Q_OS_WIN)
+#endif // HAVE_STYLE_MANAGER
 
     KLocalizedString::setApplicationDomain(QByteArrayLiteral("kshisen"));
 
